@@ -1,5 +1,5 @@
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2014, Marek Gagolewski and Bartek Tartanus
+## Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -204,5 +204,5 @@ stri_enc_detect <- function(str, filter_angle_brackets=FALSE) {
 #' @family encoding_detection
 #' @export
 stri_enc_detect2 <- function(str, locale=NULL) {
-   .Call(C_stri_enc_detect2, str, locale)
+   suppressWarnings(.Call(C_stri_enc_detect2, str, locale))
 }
